==> kde-i18n-ro-3.2.3-noarch-1.tgz: install/doinst.sh <==
( cd opt/kde/share/doc/HTML/ro/khelpcenter ; rm -rf common )
( cd opt/kde/share/doc/HTML/ro/khelpcenter ; ln -sf /opt/kde/share/doc/HTML/ro/common common )
( cd opt/kde/share/doc/HTML/ro/khelpcenter/visualdict ; rm -rf common )
( cd opt/kde/share/doc/HTML/ro/khelpcenter/visualdict ; ln -sf /opt/kde/share/doc/HTML/ro/common common )
( cd opt/kde/share/doc/HTML/ro/common ; rm -rf fdl-license )
( cd opt/kde/share/doc/HTML/ro/common ; ln -sf ../../en/common/fdl-license fdl-license )
( cd opt/kde/share/doc/HTML/ro/common ; rm -rf qpl-license.html )
( cd opt/kde/share/doc/HTML/ro/common ; ln -sf ../../en/common/qpl-license.html qpl-license.html )
( cd opt/kde/share/doc/HTML/ro/common ; rm -rf x11-license.html )
( cd opt/kde/share/doc/HTML/ro/common ; ln -sf ../../en/common/x11-license.html x11-license.html )
( cd opt/kde/share/doc/HTML/ro/common ; rm -rf 1.png )
( cd opt/kde/share/doc/HTML/ro/common ; ln -sf ../../en/common/1.png 1.png )
( cd opt/kde/share/doc/HTML/ro/common ; rm -rf xml.dcl )
( cd opt/kde/share/doc/HTML/ro/common ; ln -sf ../../en/common/xml.dcl xml.dcl )
( cd opt/kde/share/doc/HTML/ro/common ; rm -rf 2.png )
( cd opt/kde/share/doc/HTML/ro/common ; ln -sf ../../en/common/2.png 2.png )
( cd opt/kde/share/doc/HTML/ro/common ; rm -rf 3.png )
( cd opt/kde/share/doc/HTML/ro/common ; ln -sf ../../en/common/3.png 3.png )
( cd opt/kde/share/doc/HTML/ro/common ; rm -rf 4.png )
( cd opt/kde/share/doc/HTML/ro/common ; ln -sf ../../en/common/4.png 4.png )
( cd opt/kde/share/doc/HTML/ro/common ; rm -rf 5.png )
( cd opt/kde/share/doc/HTML/ro/common ; ln -sf ../../en/common/5.png 5.png )
( cd opt/kde/share/doc/HTML/ro/common ; rm -rf 6.png )
( cd opt/kde/share/doc/HTML/ro/common ; ln -sf ../../en/common/6.png 6.png )
( cd opt/kde/share/doc/HTML/ro/common ; rm -rf 7.png )
( cd opt/kde/share/doc/HTML/ro/common ; ln -sf ../../en/common/7.png 7.png )
( cd opt/kde/share/doc/HTML/ro/common ; rm -rf 8.png )
( cd opt/kde/share/doc/HTML/ro/common ; ln -sf ../../en/common/8.png 8.png )
( cd opt/kde/share/doc/HTML/ro/common ; rm -rf 9.png )
( cd opt/kde/share/doc/HTML/ro/common ; ln -sf ../../en/common/9.png 9.png )
( cd opt/kde/share/doc/HTML/ro/common ; rm -rf headerbg.png )
( cd opt/kde/share/doc/HTML/ro/common ; ln -sf ../../en/common/headerbg.png headerbg.png )
( cd opt/kde/share/doc/HTML/ro/common ; rm -rf gpl-license.html )
( cd opt/kde/share/doc/HTML/ro/common ; ln -sf ../../en/common/gpl-license.html gpl-license.html )
( cd opt/kde/share/doc/HTML/ro/common ; rm -rf mainheader.html )
( cd opt/kde/share/doc/HTML/ro/common ; ln -sf ../../en/common/mainheader.html mainheader.html )
( cd opt/kde/share/doc/HTML/ro/common ; rm -rf grad.png )
( cd opt/kde/share/doc/HTML/ro/common ; ln -sf ../../en/common/grad.png grad.png )
( cd opt/kde/share/doc/HTML/ro/common ; rm -rf kde-web.css )
( cd opt/kde/share/doc/HTML/ro/common ; ln -sf ../../en/common/kde-web.css kde-web.css )
( cd opt/kde/share/doc/HTML/ro/common ; rm -rf kde_logo_bg.png )
( cd opt/kde/share/doc/HTML/ro/common ; ln -sf ../../en/common/kde_logo_bg.png kde_logo_bg.png )
( cd opt/kde/share/doc/HTML/ro/common ; rm -rf lgpl-license.html )
( cd opt/kde/share/doc/HTML/ro/common ; ln -sf ../../en/common/lgpl-license.html lgpl-license.html )
( cd opt/kde/share/doc/HTML/ro/common ; rm -rf doxygen.css )
( cd opt/kde/share/doc/HTML/ro/common ; ln -sf ../../en/common/doxygen.css doxygen.css )
( cd opt/kde/share/doc/HTML/ro/common ; rm -rf web-doctop.png )
( cd opt/kde/share/doc/HTML/ro/common ; ln -sf ../../en/common/web-doctop.png web-doctop.png )
( cd opt/kde/share/doc/HTML/ro/common ; rm -rf kde-default.css )
( cd opt/kde/share/doc/HTML/ro/common ; ln -sf ../../en/common/kde-default.css kde-default.css )
( cd opt/kde/share/doc/HTML/ro/common ; rm -rf kmenu.png )
( cd opt/kde/share/doc/HTML/ro/common ; ln -sf ../../en/common/kmenu.png kmenu.png )
( cd opt/kde/share/doc/HTML/ro/common ; rm -rf footer.html )
( cd opt/kde/share/doc/HTML/ro/common ; ln -sf ../../en/common/footer.html footer.html )
( cd opt/kde/share/doc/HTML/ro/common ; rm -rf kde-common.css )
( cd opt/kde/share/doc/HTML/ro/common ; ln -sf ../../en/common/kde-common.css kde-common.css )
( cd opt/kde/share/doc/HTML/ro/common ; rm -rf appheader.html )
( cd opt/kde/share/doc/HTML/ro/common ; ln -sf ../../en/common/appheader.html appheader.html )
( cd opt/kde/share/doc/HTML/ro/common ; rm -rf doctop1.png )
( cd opt/kde/share/doc/HTML/ro/common ; ln -sf ../../en/common/doctop1.png doctop1.png )
( cd opt/kde/share/doc/HTML/ro/common ; rm -rf doctop2.png )
( cd opt/kde/share/doc/HTML/ro/common ; ln -sf ../../en/common/doctop2.png doctop2.png )
( cd opt/kde/share/doc/HTML/ro/common ; rm -rf shadow.png )
( cd opt/kde/share/doc/HTML/ro/common ; ln -sf ../../en/common/shadow.png shadow.png )
( cd opt/kde/share/doc/HTML/ro/common ; rm -rf kde_logo.png )
( cd opt/kde/share/doc/HTML/ro/common ; ln -sf ../../en/common/kde_logo.png kde_logo.png )
( cd opt/kde/share/doc/HTML/ro/common ; rm -rf docheadergears.png )
( cd opt/kde/share/doc/HTML/ro/common ; ln -sf ../../en/common/docheadergears.png docheadergears.png )
( cd opt/kde/share/doc/HTML/ro/common ; rm -rf fdl-license.html )
( cd opt/kde/share/doc/HTML/ro/common ; ln -sf ../../en/common/fdl-license.html fdl-license.html )
( cd opt/kde/share/doc/HTML/ro/common ; rm -rf doctop1a.png )
( cd opt/kde/share/doc/HTML/ro/common ; ln -sf ../../en/common/doctop1a.png doctop1a.png )
( cd opt/kde/share/doc/HTML/ro/common ; rm -rf 10.png )
( cd opt/kde/share/doc/HTML/ro/common ; ln -sf ../../en/common/10.png 10.png )
( cd opt/kde/share/doc/HTML/ro/common ; rm -rf doctop1b.png )
( cd opt/kde/share/doc/HTML/ro/common ; ln -sf ../../en/common/doctop1b.png doctop1b.png )
( cd opt/kde/share/doc/HTML/ro/common ; rm -rf lgpl-license )
( cd opt/kde/share/doc/HTML/ro/common ; ln -sf ../../en/common/lgpl-license lgpl-license )
( cd opt/kde/share/doc/HTML/ro/common ; rm -rf mainfooter.html )
( cd opt/kde/share/doc/HTML/ro/common ; ln -sf ../../en/common/mainfooter.html mainfooter.html )
( cd opt/kde/share/doc/HTML/ro/common ; rm -rf bottom1.png )
( cd opt/kde/share/doc/HTML/ro/common ; ln -sf ../../en/common/bottom1.png bottom1.png )
( cd opt/kde/share/doc/HTML/ro/common ; rm -rf bottom2.png )
( cd opt/kde/share/doc/HTML/ro/common ; ln -sf ../../en/common/bottom2.png bottom2.png )
( cd opt/kde/share/doc/HTML/ro/common ; rm -rf header.html )
( cd opt/kde/share/doc/HTML/ro/common ; ln -sf ../../en/common/header.html header.html )
( cd opt/kde/share/doc/HTML/ro/common ; rm -rf gpl-license )
( cd opt/kde/share/doc/HTML/ro/common ; ln -sf ../../en/common/gpl-license gpl-license )
( cd opt/kde/share/doc/HTML/ro/common ; rm -rf kde-localised.css.template )
( cd opt/kde/share/doc/HTML/ro/common ; ln -sf ../../en/common/kde-localised.css.template kde-localised.css.template )
( cd opt/kde/share/doc/HTML/ro/common ; rm -rf bsd-license.html )
( cd opt/kde/share/doc/HTML/ro/common ; ln -sf ../../en/common/bsd-license.html bsd-license.html )
( cd opt/kde/share/doc/HTML/ro/common ; rm -rf web-docbottom.png )
( cd opt/kde/share/doc/HTML/ro/common ; ln -sf ../../en/common/web-docbottom.png web-docbottom.png )
( cd opt/kde/share/doc/HTML/ro/common ; rm -rf artistic-license.html )
( cd opt/kde/share/doc/HTML/ro/common ; ln -sf ../../en/common/artistic-license.html artistic-license.html )
( cd opt/kde/share/doc/kinfocenter ; rm -rf common )
( cd opt/kde/share/doc/kinfocenter ; ln -sf /opt/kde/share/doc/HTML/..//common common )

==> kde-i18n-ro-3.3.2-noarch-1.tgz: install/doinst.sh <==
( cd opt/kde/share/doc/HTML/ro/khelpcenter/glossary ; rm -rf common )
( cd opt/kde/share/doc/HTML/ro/khelpcenter/glossary ; ln -sf /opt/kde/share/doc/HTML/ro/common common )
( cd opt/kde/share/doc/HTML/ro/khelpcenter ; rm -rf common )
( cd opt/kde/share/doc/HTML/ro/khelpcenter ; ln -sf /opt/kde/share/doc/HTML/ro/common common )
( cd opt/kde/share/doc/HTML/ro/khelpcenter/visualdict ; rm -rf common )
( cd opt/kde/share/doc/HTML/ro/khelpcenter/visualdict ; ln -sf /opt/kde/share/doc/HTML/ro/common common )
( cd opt/kde/share/doc/HTML/ro/kioslave ; rm -rf common )
( cd opt/kde/share/doc/HTML/ro/kioslave ; ln -sf /opt/kde/share/doc/HTML/ro/common common )
( cd opt/kde/share/doc/HTML/ro/common ; rm -rf fdl-license )
( cd opt/kde/share/doc/HTML/ro/common ; ln -sf ../../en/common/fdl-license fdl-license )
( cd opt/kde/share/doc/HTML/ro/common ; rm -rf qpl-license.html )
( cd opt/kde/share/doc/HTML/ro/common ; ln -sf ../../en/common/qpl-license.html qpl-license.html )
( cd opt/kde/share/doc/HTML/ro/common ; rm -rf x11-license.html )
( cd opt/kde/share/doc/HTML/ro/common ; ln -sf ../../en/common/x11-license.html x11-license.html )
( cd opt/kde/share/doc/HTML/ro/common ; rm -rf 1.png )
( cd opt/kde/share/doc/HTML/ro/common ; ln -sf ../../en/common/1.png 1.png )
( cd opt/kde/share/doc/HTML/ro/common ; rm -rf xml.dcl )
( cd opt/kde/share/doc/HTML/ro/common ; ln -sf ../../en/common/xml.dcl xml.dcl )
( cd opt/kde/share/doc/HTML/ro/common ; rm -rf 2.png )
( cd opt/kde/share/doc/HTML/ro/common ; ln -sf ../../en/common/2.png 2.png )
( cd opt/kde/share/doc/HTML/ro/common ; rm -rf 3.png )
( cd opt/kde/share/doc/HTML/ro/common ; ln -sf ../../en/common/3.png 3.png )
( cd opt/kde/share/doc/HTML/ro/common ; rm -rf 4.png )
( cd opt/kde/share/doc/HTML/ro/common ; ln -sf ../../en/common/4.png 4.png )
( cd opt/kde/share/doc/HTML/ro/common ; rm -rf 5.png )
( cd opt/kde/share/doc/HTML/ro/common ; ln -sf ../../en/common/5.png 5.png )
( cd opt/kde/share/doc/HTML/ro/common ; rm -rf 6.png )
( cd opt/kde/share/doc/HTML/ro/common ; ln -sf ../../en/common/6.png 6.png )
( cd opt/kde/share/doc/HTML/ro/common ; rm -rf 7.png )
( cd opt/kde/share/doc/HTML/ro/common ; ln -sf ../../en/common/7.png 7.png )
( cd opt/kde/share/doc/HTML/ro/common ; rm -rf 8.png )
( cd opt/kde/share/doc/HTML/ro/common ; ln -sf ../../en/common/8.png 8.png )
( cd opt/kde/share/doc/HTML/ro/common ; rm -rf 9.png )
( cd opt/kde/share/doc/HTML/ro/common ; ln -sf ../../en/common/9.png 9.png )
( cd opt/kde/share/doc/HTML/ro/common ; rm -rf headerbg.png )
( cd opt/kde/share/doc/HTML/ro/common ; ln -sf ../../en/common/headerbg.png headerbg.png )
( cd opt/kde/share/doc/HTML/ro/common ; rm -rf gpl-license.html )
( cd opt/kde/share/doc/HTML/ro/common ; ln -sf ../../en/common/gpl-license.html gpl-license.html )
( cd opt/kde/share/doc/HTML/ro/common ; rm -rf mainheader.html )
( cd opt/kde/share/doc/HTML/ro/common ; ln -sf ../../en/common/mainheader.html mainheader.html )
( cd opt/kde/share/doc/HTML/ro/common ; rm -rf grad.png )
( cd opt/kde/share/doc/HTML/ro/common ; ln -sf ../../en/common/grad.png grad.png )
( cd opt/kde/share/doc/HTML/ro/common ; rm -rf kde-web.css )
( cd opt/kde/share/doc/HTML/ro/common ; ln -sf ../../en/common/kde-web.css kde-web.css )
( cd opt/kde/share/doc/HTML/ro/common ; rm -rf kde_logo_bg.png )
( cd opt/kde/share/doc/HTML/ro/common ; ln -sf ../../en/common/kde_logo_bg.png kde_logo_bg.png )
( cd opt/kde/share/doc/HTML/ro/common ; rm -rf lgpl-license.html )
( cd opt/kde/share/doc/HTML/ro/common ; ln -sf ../../en/common/lgpl-license.html lgpl-license.html )
( cd opt/kde/share/doc/HTML/ro/common ; rm -rf doxygen.css )
( cd opt/kde/share/doc/HTML/ro/common ; ln -sf ../../en/common/doxygen.css doxygen.css )
( cd opt/kde/share/doc/HTML/ro/common ; rm -rf web-doctop.png )
( cd opt/kde/share/doc/HTML/ro/common ; ln -sf ../../en/common/web-doctop.png web-doctop.png )
( cd opt/kde/share/doc/HTML/ro/common ; rm -rf kde-default.css )
( cd opt/kde/share/doc/HTML/ro/common ; ln -sf ../../en/common/kde-default.css kde-default.css )
( cd opt/kde/share/doc/HTML/ro/common ; rm -rf kmenu.png )
( cd opt/kde/share/doc/HTML/ro/common ; ln -sf ../../en/common/kmenu.png kmenu.png )
( cd opt/kde/share/doc/HTML/ro/common ; rm -rf footer.html )
( cd opt/kde/share/doc/HTML/ro/common ; ln -sf ../../en/common/footer.html footer.html )
( cd opt/kde/share/doc/HTML/ro/common ; rm -rf kde-common.css )
( cd opt/kde/share/doc/HTML/ro/common ; ln -sf ../../en/common/kde-common.css kde-common.css )
( cd opt/kde/share/doc/HTML/ro/common ; rm -rf appheader.html )
( cd opt/kde/share/doc/HTML/ro/common ; ln -sf ../../en/common/appheader.html appheader.html )
( cd opt/kde/share/doc/HTML/ro/common ; rm -rf doctop1.png )
( cd opt/kde/share/doc/HTML/ro/common ; ln -sf ../../en/common/doctop1.png doctop1.png )
( cd opt/kde/share/doc/HTML/ro/common ; rm -rf doctop2.png )
( cd opt/kde/share/doc/HTML/ro/common ; ln -sf ../../en/common/doctop2.png doctop2.png )
( cd opt/kde/share/doc/HTML/ro/common ; rm -rf shadow.png )
( cd opt/kde/share/doc/HTML/ro/common ; ln -sf ../../en/common/shadow.png shadow.png )
( cd opt/kde/share/doc/HTML/ro/common ; rm -rf kde_logo.png )
( cd opt/kde/share/doc/HTML/ro/common ; ln -sf ../../en/common/kde_logo.png kde_logo.png )
( cd opt/kde/share/doc/HTML/ro/common ; rm -rf docheadergears.png )
( cd opt/kde/share/doc/HTML/ro/common ; ln -sf ../../en/common/docheadergears.png docheadergears.png )
( cd opt/kde/share/doc/HTML/ro/common ; rm -rf fdl-license.html )
( cd opt/kde/share/doc/HTML/ro/common ; ln -sf ../../en/common/fdl-license.html fdl-license.html )
( cd opt/kde/share/doc/HTML/ro/common ; rm -rf doctop1a.png )
( cd opt/kde/share/doc/HTML/ro/common ; ln -sf ../../en/common/doctop1a.png doctop1a.png )
( cd opt/kde/share/doc/HTML/ro/common ; rm -rf 10.png )
( cd opt/kde/share/doc/HTML/ro/common ; ln -sf ../../en/common/10.png 10.png )
( cd opt/kde/share/doc/HTML/ro/common ; rm -rf doctop1b.png )
( cd opt/kde/share/doc/HTML/ro/common ; ln -sf ../../en/common/doctop1b.png doctop1b.png )
( cd opt/kde/share/doc/HTML/ro/common ; rm -rf lgpl-license )
( cd opt/kde/share/doc/HTML/ro/common ; ln -sf ../../en/common/lgpl-license lgpl-license )
( cd opt/kde/share/doc/HTML/ro/common ; rm -rf mainfooter.html )
( cd opt/kde/share/doc/HTML/ro/common ; ln -sf ../../en/common/mainfooter.html mainfooter.html )
( cd opt/kde/share/doc/HTML/ro/common ; rm -rf bottom1.png )
( cd opt/kde/share/doc/HTML/ro/common ; ln -sf ../../en/common/bottom1.png bottom1.png )
( cd opt/kde/share/doc/HTML/ro/common ; rm -rf bottom2.png )
( cd opt/kde/share/doc/HTML/ro/common ; ln -sf ../../en/common/bottom2.png bottom2.png )
( cd opt/kde/share/doc/HTML/ro/common ; rm -rf header.html )
( cd opt/kde/share/doc/HTML/ro/common ; ln -sf ../../en/common/header.html header.html )
( cd opt/kde/share/doc/HTML/ro/common ; rm -rf gpl-license )
( cd opt/kde/share/doc/HTML/ro/common ; ln -sf ../../en/common/gpl-license gpl-license )
( cd opt/kde/share/doc/HTML/ro/common ; rm -rf kde-localised.css.template )
( cd opt/kde/share/doc/HTML/ro/common ; ln -sf ../../en/common/kde-localised.css.template kde-localised.css.template )
( cd opt/kde/share/doc/HTML/ro/common ; rm -rf bsd-license.html )
( cd opt/kde/share/doc/HTML/ro/common ; ln -sf ../../en/common/bsd-license.html bsd-license.html )
( cd opt/kde/share/doc/HTML/ro/common ; rm -rf web-docbottom.png )
( cd opt/kde/share/doc/HTML/ro/common ; ln -sf ../../en/common/web-docbottom.png web-docbottom.png )
( cd opt/kde/share/doc/HTML/ro/common ; rm -rf artistic-license.html )
( cd opt/kde/share/doc/HTML/ro/common ; ln -sf ../../en/common/artistic-license.html artistic-license.html )
( cd opt/kde/share/doc/HTML/ro/kinfocenter ; rm -rf common )
( cd opt/kde/share/doc/HTML/ro/kinfocenter ; ln -sf /opt/kde/share/doc/HTML/ro/common common )
